#[non_exhaustive]pub enum ApiError<E>{
Show 14 variants
Client {
source: E,
},
Auth {
source: AuthError,
},
UrlParse {
source: ParseError,
},
Body {
source: BodyError,
},
Json {
source: Error,
},
MovedPermanently {
location: Option<String>,
},
GitlabService {
status: StatusCode,
data: Vec<u8>,
},
DataType {
source: Error,
typename: &'static str,
},
Pagination {
source: PaginationError,
},
UnsupportedUrlBase {
url_base: UrlBase,
},
GitlabWithStatus {
status: StatusCode,
msg: String,
},
GitlabObjectWithStatus {
status: StatusCode,
obj: Value,
},
GitlabUnrecognizedWithStatus {
status: StatusCode,
obj: Value,
},
GitlabRateLimited {
rl_limit: usize,
rl_name: String,
rl_observed: usize,
rl_remaining: usize,
rl_reset: DateTime<Utc>,
retry_after: Duration,
},
}Expand description
Errors which may occur when using API endpoints.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Client
The client encountered an error.
Fields
source: EThe client error.
Auth
Authentication failed.
UrlParse
The URL failed to parse.
Fields
source: ParseErrorThe source of the error.
Body
Body data could not be created.
Json
JSON deserialization from GitLab failed.
MovedPermanently
The resource has been moved permanently.
GitlabService
GitLab returned an error without JSON information.
DataType
Failed to parse an expected data type from JSON.
Fields
Pagination
An error with pagination occurred.
Fields
source: PaginationErrorThe source of the error.
UnsupportedUrlBase
The client does not understand how to use an endpoint for the given URL base.
GitlabWithStatus
GitLab returned an error message with an HTTP error.
GitlabObjectWithStatus
GitLab returned an error object with an HTTP error.
GitlabUnrecognizedWithStatus
GitLab returned an HTTP error with JSON we did not recognize.
GitlabRateLimited
GitLab returned an error message with an HTTP error.
Fields
Implementations