#[non_exhaustive]pub enum EventAction {
Approved,
Closed,
Commented,
Created,
Destroyed,
Expired,
Joined,
Left,
Merged,
Pushed,
Reopened,
Updated,
}Expand description
Actions events may represent.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Approved
Approval of a merge request.
Closed
Closure of a merge request, issue, etc.
Commented
A comment was made.
Created
The creation of an entity.
Destroyed
The destruction of an entity.
Expired
The expiration of a membership.
Joined
The addition of a member to a project or group.
Left
The departure of a member from a project or group.
Merged
The merge of a merge request.
Pushed
A push to a project’s repository.
Reopened
The reopening of an issue.
Updated
An update to an entity.
Implementations