#[non_exhaustive]pub enum GroupProjectsOrderBy {
Id,
Name,
Path,
CreatedAt,
UpdatedAt,
Similarity,
LastActivityAt,
StarCount,
}Expand description
Keys project results may be ordered by.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Id
Order by the user ID.
Name
Order by the user display name.
Path
Order by the path.
CreatedAt
Order by the creation date of the project.
UpdatedAt
Order by the last updated date of the project.
Similarity
Order by a similarity score based on the search.
LastActivityAt
Order by the last activity date of the project.
StarCount
Order by star count.