#[non_exhaustive]pub enum GroupVariableType {
EnvVar,
File,
}Expand description
The type of a group variable.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
EnvVar
An environment variable.
The value of the variable is available as the value of the named environment variable.
File
A file variable.
The value of the variable is available in a file given by the value of the named environment variable.