Endpoint

Trait Endpoint 

pub trait Endpoint {
    // Required methods
    fn method(&self) -> Method;
    fn endpoint(&self) -> Cow<'static, str>;

    // Provided methods
    fn url_base(&self) -> UrlBase { ... }
    fn parameters(&self) -> QueryParams<'_> { ... }
    fn body(&self) -> Result<Option<(&'static str, Vec<u8>)>, BodyError> { ... }
}
A trait for providing the necessary information for a single REST API endpoint.

Required Methods

fn method(&self) -> Method

The HTTP method to use for the endpoint.

fn endpoint(&self) -> Cow<'static, str>

The path to the endpoint.

Provided Methods

fn url_base(&self) -> UrlBase

The URL base of the API endpoint.

fn parameters(&self) -> QueryParams<'_>

Query parameters for the endpoint.

fn body(&self) -> Result<Option<(&'static str, Vec<u8>)>, BodyError>

The body for the endpoint.

Returns the Content-Encoding header for the data as well as the data itself.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<E> Endpoint for &E
where E: Endpoint,

Source

fn method(&self) -> Method

Source

fn endpoint(&self) -> Cow<'static, str>

Source

fn url_base(&self) -> UrlBase

Source

fn parameters(&self) -> QueryParams<'_>

Source

fn body(&self) -> Result<Option<(&'static str, Vec<u8>)>, BodyError>

Implementors

Source

impl Endpoint for AddGroupMember<'_>

Source

impl Endpoint for AddProjectMember<'_>

Source

impl Endpoint for AllGroupMembers<'_>

Source

impl Endpoint for AllProjectMember<'_>

Source

impl Endpoint for AllProjectMembers<'_>

Source

impl Endpoint for AllRunners<'_>

Source

impl Endpoint for AllowJobTokenGroup<'_>

Source

impl Endpoint for AllowJobTokenProject<'_>

Source

impl Endpoint for AllowedJobTokenGroups<'_>

Source

impl Endpoint for AllowedJobTokenProjects<'_>

Source

impl Endpoint for ApproveMergeRequest<'_>

Source

impl Endpoint for Archive<'_>

Source

impl Endpoint for ArchiveProject<'_>

Source

impl Endpoint for BlockMergeRequest<'_>

Source

impl Endpoint for BlockUser

Source

impl Endpoint for Branch<'_>

Source

impl Endpoint for Branches<'_>

Source

impl Endpoint for CancelJob<'_>

Source

impl Endpoint for CancelPipeline<'_>

Source

impl Endpoint for CommentOnCommit<'_>

Source

impl Endpoint for Commit<'_>

Source

impl Endpoint for CommitComments<'_>

Source

impl Endpoint for CommitReferences<'_>

Source

impl Endpoint for CommitStatuses<'_>

Source

impl Endpoint for Commits<'_>

Source

impl Endpoint for CompareCommits<'_>

Source

impl Endpoint for Contributors<'_>

Source

impl Endpoint for CreateBranch<'_>

Source

impl Endpoint for CreateCommit<'_>

Source

impl Endpoint for CreateCommitStatus<'_>

Source

impl Endpoint for CreateDeployKey<'_>

Source

impl Endpoint for CreateDeployment<'_>

Source

impl Endpoint for CreateFile<'_>

Source

impl Endpoint for CreateGroup<'_>

Source

impl Endpoint for CreateGroupMilestone<'_>

Source

impl Endpoint for CreateGroupVariable<'_>

Source

impl Endpoint for gitlab::api::groups::hooks::CreateHook<'_>

Source

impl Endpoint for gitlab::api::projects::hooks::CreateHook<'_>

Source

impl Endpoint for CreateImpersonationToken<'_>

Source

impl Endpoint for CreateIssue<'_>

Source

impl Endpoint for CreateIssueAward<'_>

Source

impl Endpoint for CreateIssueLink<'_>

Source

impl Endpoint for CreateIssueNote<'_>

Source

impl Endpoint for CreateIssueNoteAward<'_>

Source

impl Endpoint for CreateLabel<'_>

Source

impl Endpoint for CreateMergeRequest<'_>

Source

impl Endpoint for CreateMergeRequestAward<'_>

Source

impl Endpoint for CreateMergeRequestDiscussion<'_>

Source

impl Endpoint for CreateMergeRequestNote<'_>

Source

impl Endpoint for CreateMergeRequestNoteAward<'_>

Source

impl Endpoint for CreateMergeRequestPipelines<'_>

Source

impl Endpoint for CreatePersonalAccessToken<'_>

Source

impl Endpoint for CreatePersonalAccessTokenForUser<'_>

Source

impl Endpoint for CreatePipeline<'_>

Source

impl Endpoint for CreatePipelineSchedule<'_>

Source

impl Endpoint for CreatePipelineScheduleVariable<'_>

Source

impl Endpoint for CreateProject<'_>

Source

impl Endpoint for CreateProjectAccessToken<'_>

Source

impl Endpoint for CreateProjectMilestone<'_>

Source

impl Endpoint for CreateProjectVariable<'_>

Source

impl Endpoint for CreateRelease<'_>

Source

impl Endpoint for CreateReleaseLink<'_>

Source

impl Endpoint for gitlab::api::runners::CreateRunner<'_>

Source

impl Endpoint for gitlab::api::users::CreateRunner<'_>

Source

impl Endpoint for CreateTag<'_>

Source

impl Endpoint for CreateUser<'_>

Source

impl Endpoint for CurrentUser

Source

impl Endpoint for gitlab::api::groups::custom_attributes::CustomAttributes<'_>

Source

impl Endpoint for gitlab::api::projects::custom_attributes::CustomAttributes<'_>

Source

impl Endpoint for gitlab::api::users::custom_attributes::CustomAttributes<'_>

Source

impl Endpoint for DeleteBranch<'_>

Source

impl Endpoint for DeleteDeployKey<'_>

Source

impl Endpoint for DeleteDeployment<'_>

Source

impl Endpoint for DeleteFile<'_>

Source

impl Endpoint for DeleteGroup<'_>

Source

impl Endpoint for DeleteGroupVariable<'_>

Source

impl Endpoint for gitlab::api::groups::hooks::DeleteHook<'_>

Source

impl Endpoint for gitlab::api::projects::hooks::DeleteHook<'_>

Source

impl Endpoint for DeleteImpersonationToken

Source

impl Endpoint for DeleteIssue<'_>

Source

impl Endpoint for DeleteIssueAward<'_>

Source

impl Endpoint for DeleteIssueLink<'_>

Source

impl Endpoint for DeleteIssueNote<'_>

Source

impl Endpoint for DeleteIssueNoteAward<'_>

Source

impl Endpoint for DeleteJobArtifacts<'_>

Source

impl Endpoint for DeleteLabel<'_>

Source

impl Endpoint for DeleteMergeRequestAward<'_>

Source

impl Endpoint for DeleteMergeRequestNoteAward<'_>

Source

impl Endpoint for DeletePackage<'_>

Source

impl Endpoint for DeletePackageFile<'_>

Source

impl Endpoint for DeletePipeline<'_>

Source

impl Endpoint for DeletePipelineSchedule<'_>

Source

impl Endpoint for DeletePipelineScheduleVariable<'_>

Source

impl Endpoint for DeleteProject<'_>

Source

impl Endpoint for DeleteProjectArtifacts<'_>

Source

impl Endpoint for DeleteProjectVariable<'_>

Source

impl Endpoint for DeleteReleaseLink<'_>

Source

impl Endpoint for DeleteRepository<'_>

Source

impl Endpoint for DeleteRepositoryTag<'_>

Source

impl Endpoint for DeleteRepositoryTags<'_>

Source

impl Endpoint for DeleteRunner

Source

impl Endpoint for DeleteRunnerByToken<'_>

Source

impl Endpoint for DeleteTag<'_>

Source

impl Endpoint for DeleteUser

Source

impl Endpoint for DeployKey<'_>

Source

impl Endpoint for gitlab::api::deploy_keys::DeployKeys

Source

impl Endpoint for gitlab::api::projects::deploy_keys::DeployKeys<'_>

Source

impl Endpoint for Deployment<'_>

Source

impl Endpoint for Deployments<'_>

Source

impl Endpoint for DisableProjectRunner<'_>

Source

impl Endpoint for DisallowJobTokenGroup<'_>

Source

impl Endpoint for DisallowJobTokenProject<'_>

Source

impl Endpoint for DownloadExport<'_>

Source

impl Endpoint for DownloadJobArtifactFile<'_>

Source

impl Endpoint for DownloadJobArtifacts<'_>

Source

impl Endpoint for DownloadRefJobArtifactFile<'_>

Source

impl Endpoint for DownloadRefJobArtifacts<'_>

Source

impl Endpoint for EditDeployKey<'_>

Source

impl Endpoint for EditDeployment<'_>

Source

impl Endpoint for EditGroup<'_>

Source

impl Endpoint for EditGroupMember<'_>

Source

impl Endpoint for EditGroupPushRule<'_>

Source

impl Endpoint for gitlab::api::groups::hooks::EditHook<'_>

Source

impl Endpoint for gitlab::api::projects::hooks::EditHook<'_>

Source

impl Endpoint for EditIssue<'_>

Source

impl Endpoint for EditIssueNote<'_>

Source

impl Endpoint for EditJobTokenScope<'_>

Source

impl Endpoint for EditLabel<'_>

Source

impl Endpoint for EditMergeRequest<'_>

Source

impl Endpoint for EditMergeRequestNote<'_>

Source

impl Endpoint for EditPages<'_>

Source

impl Endpoint for EditPipelineSchedule<'_>

Source

impl Endpoint for EditPipelineScheduleVariable<'_>

Source

impl Endpoint for EditProject<'_>

Source

impl Endpoint for EditProjectMember<'_>

Source

impl Endpoint for EditProjectPushRule<'_>

Source

impl Endpoint for EditRunner<'_>

Source

impl Endpoint for EnableDeployKey<'_>

Source

impl Endpoint for EnableProjectRunner<'_>

Source

impl Endpoint for Environment<'_>

Source

impl Endpoint for Environments<'_>

Source

impl Endpoint for EraseJob<'_>

Source

impl Endpoint for Events

Source

impl Endpoint for ExportStatus<'_>

Source

impl Endpoint for File<'_>

Source

impl Endpoint for FileRaw<'_>

Source

impl Endpoint for GetPackageFile<'_>

Source

impl Endpoint for GetReleaseLink<'_>

Source

impl Endpoint for Group<'_>

Source

impl Endpoint for GroupAccessRequest<'_>

Source

impl Endpoint for GroupAccessRequests<'_>

Source

impl Endpoint for GroupAccessRequestsApprove<'_>

Source

impl Endpoint for GroupAccessRequestsDeny<'_>

Source

impl Endpoint for GroupIssues<'_>

Source

impl Endpoint for GroupMember<'_>

Source

impl Endpoint for GroupMembers<'_>

Source

impl Endpoint for GroupProjects<'_>

Source

impl Endpoint for GroupRunners<'_>

Source

impl Endpoint for GroupSubgroups<'_>

Source

impl Endpoint for GroupVariable<'_>

Source

impl Endpoint for GroupVariables<'_>

Source

impl Endpoint for Groups<'_>

Source

impl Endpoint for gitlab::api::groups::hooks::Hook<'_>

Source

impl Endpoint for gitlab::api::projects::hooks::Hook<'_>

Source

impl Endpoint for gitlab::api::groups::hooks::Hooks<'_>

Source

impl Endpoint for gitlab::api::projects::hooks::Hooks<'_>

Source

impl Endpoint for ImpersonationToken

Source

impl Endpoint for ImpersonationTokens

Source

impl Endpoint for ImportProject<'_>

Source

impl Endpoint for ImportStatus<'_>

Source

impl Endpoint for Issue<'_>

Source

impl Endpoint for IssueAward<'_>

Source

impl Endpoint for IssueAwards<'_>

Source

impl Endpoint for IssueLink<'_>

Source

impl Endpoint for IssueLinks<'_>

Source

impl Endpoint for IssueNoteAward<'_>

Source

impl Endpoint for IssueNoteAwards<'_>

Source

impl Endpoint for IssueNotes<'_>

Source

impl Endpoint for IssueResourceLabelEvents<'_>

Source

impl Endpoint for Issues<'_>

Source

impl Endpoint for IssuesClosedBy<'_>

Source

impl Endpoint for gitlab::api::job::Job

Source

impl Endpoint for gitlab::api::projects::jobs::Job<'_>

Source

impl Endpoint for JobTokenScopes<'_>

Source

impl Endpoint for JobTrace<'_>

Source

impl Endpoint for Jobs<'_>

Source

impl Endpoint for KeepJobArtifacts<'_>

Source

impl Endpoint for Label<'_>

Source

impl Endpoint for Labels<'_>

Source

impl Endpoint for ListReleaseLinks<'_>

Source

impl Endpoint for MergeMergeRequest<'_>

Source

impl Endpoint for MergeRequest<'_>

Source

impl Endpoint for MergeRequestApprovalRules<'_>

Source

impl Endpoint for MergeRequestApprovalState<'_>

Source

impl Endpoint for MergeRequestApprovals<'_>

Source

impl Endpoint for MergeRequestAward<'_>

Source

impl Endpoint for MergeRequestAwards<'_>

Source

impl Endpoint for MergeRequestBlockees<'_>

Source

impl Endpoint for MergeRequestBlocks<'_>

Source

impl Endpoint for MergeRequestCommits<'_>

Source

impl Endpoint for MergeRequestDiffs<'_>

Source

impl Endpoint for MergeRequestDiscussions<'_>

Source

impl Endpoint for MergeRequestNoteAward<'_>

Source

impl Endpoint for MergeRequestNoteAwards<'_>

Source

impl Endpoint for MergeRequestNotes<'_>

Source

impl Endpoint for MergeRequestPipelines<'_>

Source

impl Endpoint for MergeRequestResourceLabelEvents<'_>

Source

impl Endpoint for MergeRequestReviewers<'_>

Source

impl Endpoint for gitlab::api::merge_requests::MergeRequests<'_>

Source

impl Endpoint for gitlab::api::projects::merge_requests::MergeRequests<'_>

Source

impl Endpoint for gitlab::api::projects::repository::commits::MergeRequests<'_>

Source

impl Endpoint for MergeRequestsClosing<'_>

Source

impl Endpoint for MergeTrains<'_>

Source

impl Endpoint for Namespace<'_>

Source

impl Endpoint for Package<'_>

Source

impl Endpoint for PackageFiles<'_>

Source

impl Endpoint for gitlab::api::groups::packages::Packages<'_>

Source

impl Endpoint for gitlab::api::projects::packages::Packages<'_>

Source

impl Endpoint for Pages<'_>

Source

impl Endpoint for PersonalAccessToken

Source

impl Endpoint for PersonalAccessTokenSelf

Source

impl Endpoint for PersonalAccessTokens<'_>

Source

impl Endpoint for Pipeline<'_>

Source

impl Endpoint for PipelineBridges<'_>

Source

impl Endpoint for PipelineJobs<'_>

Source

impl Endpoint for PipelineSchedule<'_>

Source

impl Endpoint for PipelineSchedulePipelines<'_>

Source

impl Endpoint for PipelineSchedules<'_>

Source

impl Endpoint for PipelineTestReport<'_>

Source

impl Endpoint for PipelineTestReportSummary<'_>

Source

impl Endpoint for PipelineVariables<'_>

Source

impl Endpoint for Pipelines<'_>

Source

impl Endpoint for PlayJob<'_>

Source

impl Endpoint for PlayPipelineSchedule<'_>

Source

impl Endpoint for Project<'_>

Source

impl Endpoint for ProjectAccessRequest<'_>

Source

impl Endpoint for ProjectAccessRequests<'_>

Source

impl Endpoint for ProjectAccessRequestsApprove<'_>

Source

impl Endpoint for ProjectAccessRequestsDeny<'_>

Source

impl Endpoint for ProjectAccessToken<'_>

Source

impl Endpoint for ProjectAccessTokens<'_>

Source

impl Endpoint for ProjectApprovalRules<'_>

Source

impl Endpoint for ProjectApprovals<'_>

Source

impl Endpoint for ProjectEvents<'_>

Source

impl Endpoint for ProjectIssues<'_>

Source

impl Endpoint for ProjectMember<'_>

Source

impl Endpoint for ProjectMembers<'_>

Source

impl Endpoint for ProjectReleaseByTag<'_>

Source

impl Endpoint for ProjectReleases<'_>

Source

impl Endpoint for ProjectRunners<'_>

Source

impl Endpoint for ProjectVariable<'_>

Source

impl Endpoint for ProjectVariables<'_>

Source

impl Endpoint for Projects<'_>

Source

impl Endpoint for PromoteLabel<'_>

Source

impl Endpoint for ProtectBranch<'_>

Source

impl Endpoint for ProtectTag<'_>

Source

impl Endpoint for ProtectedBranch<'_>

Source

impl Endpoint for ProtectedBranches<'_>

Source

impl Endpoint for ProtectedTag<'_>

Source

impl Endpoint for ProtectedTags<'_>

Source

impl Endpoint for RebaseMergeRequest<'_>

Source

impl Endpoint for RelatedMergeRequests<'_>

Source

impl Endpoint for RemoteImport<'_>

Source

impl Endpoint for RemoteImportS3<'_>

Source

impl Endpoint for RemoveGroupMember<'_>

Source

impl Endpoint for RemoveProjectMember<'_>

Source

impl Endpoint for Repositories<'_>

Source

impl Endpoint for RepositoryDetails

Source

impl Endpoint for RepositoryTagDetails<'_>

Source

impl Endpoint for RepositoryTags<'_>

Source

impl Endpoint for ResetRunnerAuthenticationToken

Source

impl Endpoint for ResetRunnerAuthenticationTokenByToken<'_>

Source

impl Endpoint for RetryJob<'_>

Source

impl Endpoint for RetryPipeline<'_>

Source

impl Endpoint for RevokePersonalAccessToken

Source

impl Endpoint for RevokePersonalAccessTokenSelf

Source

impl Endpoint for RevokeProjectAccessToken<'_>

Source

impl Endpoint for RotatePersonalAccessToken

Source

impl Endpoint for RotatePersonalAccessTokenSelf

Source

impl Endpoint for RotateProjectAccessToken<'_>

Source

impl Endpoint for Runner

Source

impl Endpoint for RunnerJobs<'_>

Source

impl Endpoint for Runners<'_>

Source

impl Endpoint for ScheduleExport<'_>

Source

impl Endpoint for ShareGroup<'_>

Source

impl Endpoint for ShareProject<'_>

Source

impl Endpoint for SharedGroupProjects<'_>

Source

impl Endpoint for Signature<'_>

Source

impl Endpoint for Tag<'_>

Source

impl Endpoint for Tags<'_>

Source

impl Endpoint for TakePipelineScheduleOwnership<'_>

Source

impl Endpoint for Tree<'_>

Source

impl Endpoint for UnapproveMergeRequest<'_>

Source

impl Endpoint for UnarchiveProject<'_>

Source

impl Endpoint for UnblockMergeRequest<'_>

Source

impl Endpoint for UnprotectBranch<'_>

Source

impl Endpoint for UnprotectTag<'_>

Source

impl Endpoint for UnpublishPages<'_>

Source

impl Endpoint for UnshareGroup<'_>

Source

impl Endpoint for UnshareProject<'_>

Source

impl Endpoint for UpdateFile<'_>

Source

impl Endpoint for UpdateGroupVariable<'_>

Source

impl Endpoint for UpdateProjectVariable<'_>

Source

impl Endpoint for UpdateReleaseLink<'_>

Source

impl Endpoint for UploadPackageFile<'_>

Source

impl Endpoint for User

Source

impl Endpoint for UserEvents<'_>

Source

impl Endpoint for UserProjects<'_>

Source

impl Endpoint for Users<'_>

Source

impl Endpoint for VerifyRunner<'_>

Source

impl<'a> Endpoint for CherryPick<'a>

Source

impl<'a> Endpoint for gitlab::api::groups::custom_attributes::CustomAttribute<'a>

Source

impl<'a> Endpoint for gitlab::api::projects::custom_attributes::CustomAttribute<'a>

Source

impl<'a> Endpoint for gitlab::api::users::custom_attributes::CustomAttribute<'a>

Source

impl<'a> Endpoint for gitlab::api::groups::custom_attributes::DeleteCustomAttribute<'a>

Source

impl<'a> Endpoint for gitlab::api::projects::custom_attributes::DeleteCustomAttribute<'a>

Source

impl<'a> Endpoint for gitlab::api::users::custom_attributes::DeleteCustomAttribute<'a>

Source

impl<'a> Endpoint for gitlab::api::groups::custom_attributes::EditCustomAttribute<'a>

Source

impl<'a> Endpoint for gitlab::api::projects::custom_attributes::EditCustomAttribute<'a>

Source

impl<'a> Endpoint for gitlab::api::users::custom_attributes::EditCustomAttribute<'a>

Source

impl<'a> Endpoint for StarProject<'a>

Source

impl<'a> Endpoint for Starrers<'a>

Source

impl<'a> Endpoint for UnstarProject<'a>

Source

impl<E> Endpoint for Sudo<'_, E>
where E: Endpoint,