[−][src]Enum gitlab::types::NoteableInternalId
The internal ID of an entity a note is attached to (internal to a project). GitLab only has this for notes attached to issues and merge requests.
Variants
Issue(IssueInternalId)The internal ID of the issue for an issue note.
MergeRequest(MergeRequestInternalId)The internal ID of the merge request for a merge request note.