Struct gitlab::types::Namespace [] [src]

pub struct Namespace {
    pub path: String,
    pub name: String,
    pub kind: NamespaceKind,
    pub full_path: String,
    pub members_count_with_descendants: Option<u64>,
    // some fields omitted
}

An entity which can own projects.

Fields

The URL of the namespace.

The name of the namespace.

The kind of the namespace.

Number of members in the namespace and its descendants.

Only available when talking to GitLab as a user that can admin the namespace.

Methods

impl Namespace
[src]

[src]

The ID of the namespace.