Struct gitlab::types::Note
[−]
[src]
pub struct Note {
pub id: NoteId,
pub body: String,
pub attachment: Option<String>,
pub author: UserBasic,
pub created_at: DateTime<UTC>,
pub updated_at: DateTime<UTC>,
pub system: bool,
pub noteable_type: NoteType,
pub upvote: bool,
pub downvote: bool,
// some fields omitted
}A comment on an entity.
Fields
id: NoteId
The ID of the note.
body: String
The content of the note.
attachment: Option<String>
The URL of an attachment to the note.
The author of the note.
created_at: DateTime<UTC>
When the note was created.
updated_at: DateTime<UTC>
When the note was last updated.
system: bool
Whether the note was created by a user or in response to an external action.
System notes include indications that the commit, issue, etc. was referenced elsewhere, a milestone, assignee, or label change, status chages, and so on.
noteable_type: NoteType
The type of entity the note is attached to.
upvote: bool
Whether the note is an upvote for the entity or not.
downvote: bool
Whether the note is a downvote for the entity or not.
Methods
impl Note[src]
fn noteable_id(&self) -> Option<NoteableId>
The ID of the entity the note is attached to.