[−][src]Struct gitlab::types::ProjectHook
A web hook to notify of project events.
Fields
id: HookIdThe ID of the hook.
url: StringThe URL to contact.
created_at: DateTime<Utc>When the hook was created.
project_id: ProjectIdThe project associated with the hook.
push_events: boolWhether the hook is contacted for push events.
push_events_branch_filter: Option<String>Filter branches for which the hook is contacted for push events.
tag_push_events: boolWhether the hook is contacted for tag push events.
issues_events: boolWhether the hook is contacted for issue events.
confidential_issues_events: Option<bool>Whether the hook is contacted for confidential issue events.
merge_requests_events: boolWhether the hook is contacted for merge request events.
note_events: boolWhether the hook is contacted for note events.
confidential_note_events: Option<bool>Whether the hook is contacted for confidential note events.
repository_update_events: boolWhether the hook is contacted for repository update events.
enable_ssl_verification: boolWhether the communication with the hook is verified using TLS certificates.
job_events: boolWhether the hook is contacted for job events.
pipeline_events: boolWhether the hook is contacted for pipeline events.
wiki_page_events: boolWhether the hook is contacted for wiki page events.