[−][src]Struct gitlab::types::RepoBranch
A branch on a repository.
Fields
name: StringThe name of the branch.
commit: Option<RepoCommit>The commit of the branch.
merged: Option<bool>Whether the branch is merged into the main branch or not.
protected: Option<bool>Whether the branch is protected or not.
developers_can_push: Option<bool>Whether the developers can push directly to the branch or not.
developers_can_merge: Option<bool>Whether the developers can merge into the branch or not.
can_push: Option<bool>Whether the current user can push to the branch.
default: Option<bool>Whether the branch is the repository default branch.