Struct gitlab::types::RepoDiff
[−]
[src]
pub struct RepoDiff {
pub old_path: String,
pub new_path: String,
pub a_mode: String,
pub b_mode: String,
pub diff: String,
pub new_file: bool,
pub renamed_file: bool,
pub deleted_file: bool,
}A diff within a repository.
Fields
old_path: String
The path on the old side of the diff.
new_path: String
The path on the new side of the diff.
a_mode: String
The mode on the old side of the diff.
b_mode: String
The mode on the new side of the diff.
diff: String
new_file: bool
Whether the diff indicates the addition of a file.
renamed_file: bool
Whether the diff indicates the rename of a file.
deleted_file: bool
Whether the diff indicates the deletion of a file.